.. Copyright NTESS. See COPYRIGHT file for details.

   SPDX-License-Identifier: MIT



.. _hpc_connect.hookspec:

hookspec
========

.. automodule:: hpc_connect.hookspec
   :members:
   :undoc-members:
   :show-inheritance:
